import { WebClient } from "ticketengine-sdk";
import { Customer, EventPrice, Offer, Order, OrderMessage, ProductDefinition, ProductPrice } from "./Model";
import { OrderValidator } from "./OrderValidator";
export declare class Cart {
    client: WebClient;
    retryPolicy: number[];
    errorMessages: {
        [key: string]: string;
    };
    constructor(options: CartOptions);
    getClient(): WebClient;
    login(username: string, password: string): Promise<void>;
    isTokenExpired(): boolean;
    getEvent(eventId: string): Promise<Event>;
    getEventPrices(eventId: string, customerId?: string | null, salesChannelId?: string | null, preferredLanguageCode?: string | null, capacityLocationPath?: string | null): Promise<Array<EventPrice>>;
    getProductDefinition(productDefinitionId: string): Promise<ProductDefinition>;
    getProductPrices(productDefinitionId: string, customerId?: string | null, salesChannelId?: string | null, preferredLanguageCode?: string | null): Promise<Array<ProductPrice>>;
    getCustomer(customerId: string): Promise<Customer>;
    getOrderMessages(stage: string, orderId: string | null, eventId: string | null, productDefinitionId: string | null, customerId?: string | null, salesChannelId?: string | null, preferredLanguageCode?: string | null): Promise<OrderMessage[]>;
    getOffers(orderId: string | null, customerId?: string | null, salesChannelId?: string | null, preferredLanguageCode?: string | null): Promise<Offer[]>;
    getOrder(orderId: string, validator?: OrderValidator, retryPolicy?: Array<number>, forceReload?: boolean, forceOrder?: boolean): Promise<Order>;
    private fetchOrder;
    createOrder(): Promise<void>;
    cancelOrder(orderId?: string, reason?: string): Promise<void>;
    cancelReservation(orderId?: string, reason?: string): Promise<void>;
    addItems(items: Array<AddItem>): Promise<void>;
    removeItems(items: Array<RemoveItem>): Promise<void>;
    changeItems(addItems: AddItem[] | undefined, removeItems: Array<RemoveItem>): Promise<void>;
    private mapToCartOperations;
    getItemCount(): Promise<number>;
    addToken(token: string): Promise<void>;
    acceptOffer(offerId: string): Promise<void>;
    reserve(email?: string, timeoutOn?: string): Promise<void>;
    checkout(email?: string, payments?: Array<Payment>, remark?: string, optInOn?: string[]): Promise<CheckoutResult>;
    private createPayment;
    getOrderId(): string;
    private static setOrder;
    hasOrder(): boolean;
    clearOrder(): void;
    setCustomer(customerId: string): Promise<void>;
    removeCustomer(): Promise<void>;
    private static setCustomerId;
    getCustomerId(): string;
    hasCustomerId(): boolean;
    getSalesChannelId(): string;
    setSalesChannelId(salesChannelId: string): void;
    hasSalesChannelId(): boolean;
    clearSalesChannelId(): void;
    getRegisterId(): string;
    setRegisterId(registerId: string): void;
    hasRegisterId(): boolean;
    clearRegisterId(): void;
    getPreferredLanguageCode(): string;
    setPreferredLanguageCode(preferredLanguageCode: string): void;
    hasPreferredLanguageCode(): boolean;
    clearPreferredLanguageCode(): void;
    setErrorMessages(errorMessages: {
        [key: string]: string;
    }): void;
    private getErrorMessage;
    private static isAccessCartItem;
    private static isProductCartItem;
    private static isBatchAccessCartItems;
    private sleep;
}
export interface CartOptions {
    salesChannelId: string;
    registerId: string;
    customerId?: string;
    clientId?: string;
    clientSecret?: string;
    scope?: string;
    authUrl?: string;
    adminApiUrl?: string;
    graphApiUrl?: string;
    clearTokenOnSetAuthUrl?: boolean;
    preferredLanguageCode?: string;
    errorMessages?: {
        [key: string]: string;
    };
}
export interface AddItem {
}
export interface AddAccessItem extends AddItem {
    eventManagerId: string;
    eventId: string;
    accessDefinitionId: string;
    requestedConditionPath: Array<string>;
    capacityLocationPath?: string;
}
export interface AddProductItem extends AddItem {
    productDefinitionId: string;
    requestedConditionPath: Array<string>;
}
export interface RemoveItem {
    orderLineItemId: string;
}
export interface BatchAddAccessItems extends AddItem {
    eventManagerId: string;
    eventId: string;
    accessDefinitionId: string;
    quantity: number;
    requestedConditionPath: Array<string>;
    capacityLocationPath?: string;
}
export interface CheckoutResult {
    paymentResults: Array<PaymentResult>;
}
export interface Payment {
    currencyCode: string;
    amount: number;
    method?: string | null;
    token?: string | null;
    loyaltyCardType?: string | null;
    loyaltyCardId?: string | null;
    loyaltyCardPin?: string | null;
}
export interface PaymentResult {
    paymentId: string;
    action?: PaymentAction;
}
export interface PaymentAction {
}
export interface RedirectToPaymentPage extends PaymentAction {
    paymentUrl?: string;
}
