import { LineItemStatus, Order, OrderStatus } from "./Model";
export interface OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsCompleted implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsTimeout implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsCanceled implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsPending implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsCheckedOut implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsReserved implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsPaid implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsEmpty implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsInFinalState implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class IsProcessingPayment implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class HasCustomer implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class HasToken implements OrderValidator {
    private readonly token;
    constructor(token: string);
    validate(order: Order): Boolean;
}
export declare class HasStatus implements OrderValidator {
    private readonly status;
    constructor(status: OrderStatus[]);
    validate(order: Order): Boolean;
}
export declare class HasPaymentWithCurrencyCode implements OrderValidator {
    private readonly currencyCodes;
    constructor(currencyCodes: string[]);
    validate(order: Order): Boolean;
}
export declare class HasItemsWithStatus implements OrderValidator {
    private readonly status;
    constructor(status: LineItemStatus[]);
    validate(order: Order): Boolean;
}
export declare class ItemsHaveStatus implements OrderValidator {
    private readonly orderLineIds;
    private status;
    constructor(orderLineIds: string[], status: LineItemStatus);
    validate(order: Order): Boolean;
}
export declare class ItemsHaveStatusOneOf implements OrderValidator {
    private readonly orderLineIds;
    private status;
    constructor(orderLineIds: string[], status: LineItemStatus[]);
    validate(order: Order): Boolean;
}
export declare class NeedsPaymentWithCurrency implements OrderValidator {
    private readonly currencyCode;
    constructor(currencyCode: string);
    validate(order: Order): Boolean;
}
export declare class NeedsPaymentWithIsoCurrency implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class NeedsPaymentWithCustomCurrency implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class NeedsLoyaltyCardPayment implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class ValidateItemsStatus implements OrderValidator {
    private readonly reservedOrderLineIds;
    private readonly removedOrderLineIds;
    private readonly completedOrderLineIds;
    constructor(reservedOrderLineIds?: string[], removedOrderLineIds?: string[], completedOrderLineIds?: string[]);
    validate(order: Order): Boolean;
}
export declare class CanReserve implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class CanCheckout implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class CanPay implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class CanPayOnline implements OrderValidator {
    validate(order: Order): Boolean;
}
export declare class NullValidator implements OrderValidator {
    validate(order: Order): Boolean;
}
