"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NullValidator = exports.CanPayOnline = exports.CanPay = exports.CanCheckout = exports.CanReserve = exports.ValidateItemsStatus = exports.NeedsLoyaltyCardPayment = exports.NeedsPaymentWithCustomCurrency = exports.NeedsPaymentWithIsoCurrency = exports.NeedsPaymentWithCurrency = exports.ItemsHaveStatusOneOf = exports.ItemsHaveStatus = exports.HasItemsWithStatus = exports.HasPaymentWithCurrencyCode = exports.HasStatus = exports.HasToken = exports.HasCustomer = exports.IsProcessingPayment = exports.IsInFinalState = exports.IsEmpty = exports.IsPaid = exports.IsReserved = exports.IsCheckedOut = exports.IsPending = exports.IsCanceled = exports.IsTimeout = exports.IsCompleted = void 0;
var Model_1 = require("./Model");
var IsCompleted = /** @class */ (function () {
    function IsCompleted() {
    }
    IsCompleted.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.completed;
    };
    return IsCompleted;
}());
exports.IsCompleted = IsCompleted;
var IsTimeout = /** @class */ (function () {
    function IsTimeout() {
    }
    IsTimeout.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.timeout;
    };
    return IsTimeout;
}());
exports.IsTimeout = IsTimeout;
var IsCanceled = /** @class */ (function () {
    function IsCanceled() {
    }
    IsCanceled.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.canceled;
    };
    return IsCanceled;
}());
exports.IsCanceled = IsCanceled;
var IsPending = /** @class */ (function () {
    function IsPending() {
    }
    IsPending.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.pending;
    };
    return IsPending;
}());
exports.IsPending = IsPending;
var IsCheckedOut = /** @class */ (function () {
    function IsCheckedOut() {
    }
    IsCheckedOut.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.checkOut;
    };
    return IsCheckedOut;
}());
exports.IsCheckedOut = IsCheckedOut;
var IsReserved = /** @class */ (function () {
    function IsReserved() {
    }
    IsReserved.prototype.validate = function (order) {
        return order && order.status === Model_1.OrderStatus.reserved;
    };
    return IsReserved;
}());
exports.IsReserved = IsReserved;
var IsPaid = /** @class */ (function () {
    function IsPaid() {
    }
    IsPaid.prototype.validate = function (order) {
        return order && order.paymentStatus === Model_1.PaymentStatus.paid;
    };
    return IsPaid;
}());
exports.IsPaid = IsPaid;
var IsEmpty = /** @class */ (function () {
    function IsEmpty() {
    }
    IsEmpty.prototype.validate = function (order) {
        if (!order || !order.lineItems) {
            return true;
        }
        return order.lineItems.filter(function (item) {
            // const pendingStatusses: Array<LineItemStatus> = [LineItemStatus.reserved];
            // return pendingStatusses.includes(item.status)
            var status = [Model_1.LineItemStatus.removed, Model_1.LineItemStatus.returned];
            return !status.includes(item.status);
        }).length === 0;
        // if(!order || !order.lineItems) {
        //     return true;
        // }
        // return order.lineItems.length === 0
    };
    return IsEmpty;
}());
exports.IsEmpty = IsEmpty;
var IsInFinalState = /** @class */ (function () {
    function IsInFinalState() {
    }
    IsInFinalState.prototype.validate = function (order) {
        var finalStates = [Model_1.OrderStatus.completed, Model_1.OrderStatus.canceled, Model_1.OrderStatus.timeout, Model_1.OrderStatus.failed];
        return order && finalStates.includes(order.status);
    };
    return IsInFinalState;
}());
exports.IsInFinalState = IsInFinalState;
var IsProcessingPayment = /** @class */ (function () {
    function IsProcessingPayment() {
    }
    IsProcessingPayment.prototype.validate = function (order) {
        var hasPayments = order && order.payments ? order.payments.length > 0 : false;
        return order && order.status === Model_1.OrderStatus.checkOut && order.paymentStatus !== Model_1.PaymentStatus.paid && hasPayments;
    };
    return IsProcessingPayment;
}());
exports.IsProcessingPayment = IsProcessingPayment;
var HasCustomer = /** @class */ (function () {
    function HasCustomer() {
    }
    HasCustomer.prototype.validate = function (order) {
        return order && order.customer;
    };
    return HasCustomer;
}());
exports.HasCustomer = HasCustomer;
var HasToken = /** @class */ (function () {
    function HasToken(token) {
        this.token = token;
    }
    HasToken.prototype.validate = function (order) {
        return order && order.tokens ? order.tokens.map(function (t) { return t.token; }).includes(this.token) : false;
    };
    return HasToken;
}());
exports.HasToken = HasToken;
var HasStatus = /** @class */ (function () {
    function HasStatus(status) {
        this.status = status;
    }
    HasStatus.prototype.validate = function (order) {
        return order && order.status && this.status.includes(order.status);
    };
    return HasStatus;
}());
exports.HasStatus = HasStatus;
var HasPaymentWithCurrencyCode = /** @class */ (function () {
    function HasPaymentWithCurrencyCode(currencyCodes) {
        this.currencyCodes = currencyCodes;
    }
    HasPaymentWithCurrencyCode.prototype.validate = function (order) {
        // returns true when array contains all values that are in target array
        var includesAll = function (arr, target) { return target.every(function (v) { return arr.includes(v); }); };
        if (!order || !order.payments) {
            return false;
        }
        return includesAll(order.payments.map(function (p) { return p.currency.code; }), this.currencyCodes);
    };
    return HasPaymentWithCurrencyCode;
}());
exports.HasPaymentWithCurrencyCode = HasPaymentWithCurrencyCode;
var HasItemsWithStatus = /** @class */ (function () {
    function HasItemsWithStatus(status) {
        this.status = status;
    }
    HasItemsWithStatus.prototype.validate = function (order) {
        var _this = this;
        if (!order || !order.lineItems) {
            return false;
        }
        return order.lineItems.filter(function (item) {
            // const pendingStatusses: Array<LineItemStatus> = [LineItemStatus.pending, LineItemStatus.awaitingClaim];
            return _this.status.includes(item.status);
        }).length > 0;
    };
    return HasItemsWithStatus;
}());
exports.HasItemsWithStatus = HasItemsWithStatus;
// export class HasPendingItems implements OrderValidator {
//     validate(order: Order): Boolean {
//         if(!order || !order.lineItems) {
//             return false;
//         }
//         return order.lineItems.filter((item) => {
//             const pendingStatusses: Array<LineItemStatus> = [LineItemStatus.pending, LineItemStatus.awaitingClaim];
//             return pendingStatusses.includes(item.status)
//         }).length > 0
//     }
// }
var ItemsHaveStatus = /** @class */ (function () {
    function ItemsHaveStatus(orderLineIds, status) {
        this.orderLineIds = orderLineIds;
        this.status = status;
    }
    ItemsHaveStatus.prototype.validate = function (order) {
        var _this = this;
        if (!order || !order.lineItems) {
            return false;
        }
        for (var i = 0; i < this.orderLineIds.length; i++) {
            if (!order.lineItems.filter(function (l) { return l.status === _this.status; }).map(function (l) { return l.id; }).includes(this.orderLineIds[i]))
                return false;
        }
        return true;
    };
    return ItemsHaveStatus;
}());
exports.ItemsHaveStatus = ItemsHaveStatus;
var ItemsHaveStatusOneOf = /** @class */ (function () {
    function ItemsHaveStatusOneOf(orderLineIds, status) {
        this.orderLineIds = orderLineIds;
        this.status = status;
    }
    ItemsHaveStatusOneOf.prototype.validate = function (order) {
        if (!order || !order.lineItems) {
            return false;
        }
        // for(let i = 0; i < this.orderLineIds.length; i++){
        //     if(!order.lineItems.filter(l => this.status.includes(l.status)).map(l => l.id).includes(this.orderLineIds[i])) return false;
        // }
        for (var i = 0; i < order.lineItems.length; i++) {
            if (this.orderLineIds.includes(order.lineItems[i].id) && !this.status.includes(order.lineItems[i].status)) {
                return false;
            }
        }
        return true;
    };
    return ItemsHaveStatusOneOf;
}());
exports.ItemsHaveStatusOneOf = ItemsHaveStatusOneOf;
var NeedsPaymentWithCurrency = /** @class */ (function () {
    function NeedsPaymentWithCurrency(currencyCode) {
        this.currencyCode = currencyCode;
    }
    NeedsPaymentWithCurrency.prototype.validate = function (order) {
        return order && order.requiredPayments ? order.requiredPayments.map(function (p) { return p.currency.code; }).includes(this.currencyCode) : false;
    };
    return NeedsPaymentWithCurrency;
}());
exports.NeedsPaymentWithCurrency = NeedsPaymentWithCurrency;
var NeedsPaymentWithIsoCurrency = /** @class */ (function () {
    function NeedsPaymentWithIsoCurrency() {
    }
    NeedsPaymentWithIsoCurrency.prototype.validate = function (order) {
        var payments = order && order.payments ? order.payments.filter(function (p) { return !['refused', 'cancelled'].includes(p.status); }) : [];
        if (order && order.requiredPayments) {
            var _loop_1 = function (i) {
                var currencyCode = order.requiredPayments[i].currency.code;
                var requiredAmount = order.requiredPayments[i].amount;
                var paidAmount = payments.filter(function (p) { return p.currency.code === currencyCode; }).reduce(function (total, p) { return total + p.amount; }, 0);
                if (currencyCode.length === 3 && paidAmount < requiredAmount) {
                    return { value: true };
                }
            };
            for (var i = 0; i < order.requiredPayments.length; i++) {
                var state_1 = _loop_1(i);
                if (typeof state_1 === "object")
                    return state_1.value;
            }
        }
        return false;
    };
    return NeedsPaymentWithIsoCurrency;
}());
exports.NeedsPaymentWithIsoCurrency = NeedsPaymentWithIsoCurrency;
var NeedsPaymentWithCustomCurrency = /** @class */ (function () {
    function NeedsPaymentWithCustomCurrency() {
    }
    NeedsPaymentWithCustomCurrency.prototype.validate = function (order) {
        var payments = order && order.payments ? order.payments.filter(function (p) { return !['refused', 'cancelled'].includes(p.status); }) : [];
        if (order && order.requiredPayments) {
            var _loop_2 = function (i) {
                var currencyCode = order.requiredPayments[i].currency.code;
                var requiredAmount = order.requiredPayments[i].amount;
                var paidAmount = payments.filter(function (p) { return p.currency.code === currencyCode; }).reduce(function (total, p) { return total + p.amount; }, 0);
                if (currencyCode.length > 3 && paidAmount < requiredAmount) {
                    return { value: true };
                }
            };
            for (var i = 0; i < order.requiredPayments.length; i++) {
                var state_2 = _loop_2(i);
                if (typeof state_2 === "object")
                    return state_2.value;
            }
        }
        return false;
    };
    return NeedsPaymentWithCustomCurrency;
}());
exports.NeedsPaymentWithCustomCurrency = NeedsPaymentWithCustomCurrency;
var NeedsLoyaltyCardPayment = /** @class */ (function () {
    function NeedsLoyaltyCardPayment() {
    }
    NeedsLoyaltyCardPayment.prototype.validate = function (order) {
        var payments = order && order.payments ? order.payments.filter(function (p) { return !['refused', 'cancelled'].includes(p.status); }) : [];
        if (order && order.requiredLoyaltyCardPayments) {
            var _loop_3 = function (i) {
                var currencyCode = order.requiredLoyaltyCardPayments[i].currency.code;
                var requiredAmount = order.requiredLoyaltyCardPayments[i].amount;
                var cardType = order.requiredLoyaltyCardPayments[i].cardType;
                var loyaltyCardPayments = payments.filter(function (p) { return p.currency.code === currencyCode && p.psp === 'loyalty' && p.method === cardType; });
                var paidAmount = loyaltyCardPayments.reduce(function (total, p) { return total + p.amount; }, 0);
                if (loyaltyCardPayments.length === 0 || paidAmount < requiredAmount) {
                    return { value: true };
                }
            };
            for (var i = 0; i < order.requiredLoyaltyCardPayments.length; i++) {
                var state_3 = _loop_3(i);
                if (typeof state_3 === "object")
                    return state_3.value;
            }
        }
        return false;
    };
    return NeedsLoyaltyCardPayment;
}());
exports.NeedsLoyaltyCardPayment = NeedsLoyaltyCardPayment;
var ValidateItemsStatus = /** @class */ (function () {
    function ValidateItemsStatus(reservedOrderLineIds, removedOrderLineIds, completedOrderLineIds) {
        if (reservedOrderLineIds === void 0) { reservedOrderLineIds = []; }
        if (removedOrderLineIds === void 0) { removedOrderLineIds = []; }
        if (completedOrderLineIds === void 0) { completedOrderLineIds = []; }
        this.reservedOrderLineIds = reservedOrderLineIds;
        this.removedOrderLineIds = removedOrderLineIds;
        this.completedOrderLineIds = completedOrderLineIds;
    }
    ValidateItemsStatus.prototype.validate = function (order) {
        var reservedValidator = new ItemsHaveStatus(this.reservedOrderLineIds, Model_1.LineItemStatus.reserved);
        var removedValidator = new ItemsHaveStatus(this.removedOrderLineIds, Model_1.LineItemStatus.removed);
        var completedValidator = new ItemsHaveStatus(this.completedOrderLineIds, Model_1.LineItemStatus.completed);
        return reservedValidator.validate(order) && removedValidator.validate(order) && completedValidator.validate(order);
    };
    return ValidateItemsStatus;
}());
exports.ValidateItemsStatus = ValidateItemsStatus;
var CanReserve = /** @class */ (function () {
    function CanReserve() {
    }
    CanReserve.prototype.validate = function (order) {
        var isEmpty = new IsEmpty();
        // const isInFinalState: IsInFinalState = new IsInFinalState();
        // const isCheckedOut: IsCheckedOut = new IsCheckedOut();
        // const isReserved: IsReserved = new IsReserved();
        var hasPendingItems = new HasItemsWithStatus([Model_1.LineItemStatus.pending, Model_1.LineItemStatus.awaitingClaim]);
        return order && (order.status === Model_1.OrderStatus.pending)
            && !isEmpty.validate(order)
            // && !isInFinalState.validate(order)
            // && !isCheckedOut.validate(order)
            // && !isReserved.validate(order)
            && !hasPendingItems.validate(order);
    };
    return CanReserve;
}());
exports.CanReserve = CanReserve;
var CanCheckout = /** @class */ (function () {
    function CanCheckout() {
    }
    CanCheckout.prototype.validate = function (order) {
        var isEmpty = new IsEmpty();
        // const hasPendingItems: HasPendingItems = new HasPendingItems();
        var hasPendingItems = new HasItemsWithStatus([Model_1.LineItemStatus.pending, Model_1.LineItemStatus.awaitingClaim]);
        return order && (order.status === Model_1.OrderStatus.pending || order.status === Model_1.OrderStatus.reserved)
            && !isEmpty.validate(order)
            && !hasPendingItems.validate(order);
    };
    return CanCheckout;
}());
exports.CanCheckout = CanCheckout;
var CanPay = /** @class */ (function () {
    function CanPay() {
    }
    CanPay.prototype.validate = function (order) {
        var isEmpty = new IsEmpty();
        // const hasPendingItems: HasPendingItems = new HasPendingItems();
        var hasPendingItems = new HasItemsWithStatus([Model_1.LineItemStatus.pending, Model_1.LineItemStatus.awaitingClaim]);
        return order && order.paymentStatus !== Model_1.PaymentStatus.paid
            && (order.status === Model_1.OrderStatus.pending || order.status === Model_1.OrderStatus.reserved || order.status === Model_1.OrderStatus.checkOut)
            && !isEmpty.validate(order)
            && !hasPendingItems.validate(order);
    };
    return CanPay;
}());
exports.CanPay = CanPay;
var CanPayOnline = /** @class */ (function () {
    function CanPayOnline() {
    }
    CanPayOnline.prototype.validate = function (order) {
        // const canPay: CanPay = new CanPay();
        var paymentCurrencies = order && order.requiredPayments ? order.requiredPayments.map(function (rp) { return rp.currency.code; }) : [];
        // return canPay.validate(order) && !paymentCurrencies.includes('CINEVILLE');
        return !paymentCurrencies.includes('CINEVILLE');
    };
    return CanPayOnline;
}());
exports.CanPayOnline = CanPayOnline;
var NullValidator = /** @class */ (function () {
    function NullValidator() {
    }
    NullValidator.prototype.validate = function (order) {
        return true;
    };
    return NullValidator;
}());
exports.NullValidator = NullValidator;
